@@ -73,18 +73,17 @@ async def grade_assignment(submission, sec='3', assignment='lab01', solutions_pa
                                          assign_type=assign_type,
                                          sec=sec,
                                          assignment=assignment)
+        command = [
+            'otter', 'grade',
+            '-a', zip_path, 
+            '-p', submission
+        ]
         # command = [
-        #     'otter', 'grade',
+        #     'otter', 'run',
         #     '-a',
-        #     zip_path, '-p',
+        #     zip_path,
         #     submission
         # ]
-        command = [
-            'otter', 'run',
-            '-a',
-            zip_path,
-            submission
-        ]
         process = await asyncio.create_subprocess_exec(
             *command,
             stdin=asyncio.subprocess.PIPE,
@@ -102,18 +101,18 @@ async def grade_assignment(submission, sec='3', assignment='lab01', solutions_pa
             if 'Killed' in line:
                 # Our container was killed, so let's just skip this one
                 raise Exception(f"Container was killed -- nothing will work: {submission}")
-        # grade = stdout.decode("utf-8").strip()
-        # if grade is None or grade == '':
-        #     cmd = ' '.join(command)
-        #     raise Exception(f"Unable to determine grade coming from otter on: {submission} using this commnad: {cmd}")
-        lines = stdout.decode("utf-8").strip().split("\n")
-        grade = None
-        for line in lines:
-            if "Total Score" in line:
-                grade = line.split(" ")[5][1:-2]
-        if grade is None:
-            raise Exception(f"Unable to determine grade coming from otter on: {submission}")
-        return float(grade) / 100
+        grade = stdout.decode("utf-8").strip()
+        if grade is None or grade == '':
+            cmd = ' '.join(command)
+            raise Exception(f"Unable to determine grade coming from otter on: {submission} using this commnad: {cmd}")
+        # lines = stdout.decode("utf-8").strip().split("\n")
+        # grade = None
+        # for line in lines:
+        #     if "Total Score" in line:
+        #         grade = line.split(" ")[5][1:-2]
+        # if grade is None:
+        #     raise Exception(f"Unable to determine grade coming from otter on: {submission}")
+        return float(grade)
     except asyncio.TimeoutError:
         raise Exception(f'Grading timed out for {submission}')
     except Exception as e:
