@@ -394,7 +394,10 @@ def log_info_csv(username, course, section, assignment, msg):
     :param assignment: the assignment
     :param msg: optional message to logs
     """
-    write_logs(username, course, section, assignment, msg, None, "info", f'{os.environ.get("ENVIRONMENT")}-logs')
+    try:
+        write_logs(username, course, section, assignment, msg, None, "info", f'{os.environ.get("ENVIRONMENT")}-logs')
+    except:
+        print("here")
 
 def log_error_csv(username, course, section, assignment, msg):
     """
@@ -407,7 +410,10 @@ def log_error_csv(username, course, section, assignment, msg):
     :param assignment: the assignment
     :param msg: optional message to logs
     """
-    write_logs(username, course, section, assignment, msg, str(traceback.format_exc()), "error", f'{os.environ.get("ENVIRONMENT")}-logs')
+    try:
+        write_logs(username, course, section, assignment, msg, str(traceback.format_exc()), "error", f'{os.environ.get("ENVIRONMENT")}-logs')
+    except:
+        print("here1")
 
 def log_tornado_issues(msg, type):
     """
@@ -427,7 +433,8 @@ def log_tornado_issues(msg, type):
         }
         return db.collection(f'{os.environ.get("ENVIRONMENT")}-tornado-logs').add(data)
     except Exception as err:
-        raise Exception(f"Error inserting {type} log into Google FireStore: {data}") from err
+        #raise Exception(f"Error inserting {type} log into Google FireStore: {data}") from err
+        print("here 34")
 
 def save_submission(username, course, section, assignment, notebook):
     """
@@ -500,7 +507,6 @@ def main():
     """
     try:
         start_server()
-        log_tornado_issues("Server starting", "info")
         tornado.ioloop.IOLoop.current().start()
     except Exception:
         log_tornado_issues("Server start up issues", "error")
